/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2013 Frederik Heber. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * StoreSessionAction.cpp
 *
 *  Created on: Aug 23, 2013
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "CodePatterns/Log.hpp"

#include <fstream>

#include "Actions/CommandAction/StoreSessionAction.hpp"
#include "Actions/ActionQueue.hpp"

using namespace MoleCuilder;

// and construct the stuff
#include "StoreSessionAction.def"
#include "Action_impl_pre.hpp"
/** =========== define the function ====================== */
ActionState::ptr CommandStoreSessionAction::performCall() {

  LOG(1, "INFO: Storing session to file " << params.filename.get().string());

  std::string filename(params.filename.get().string());
  if (params.sessiontype.get() == "cli") {
    // open in append mode as we don't have argv[0] available here
    std::ofstream output(filename.c_str(), std::fstream::app);
    ActionQueue::getInstance().outputAsCLI(output);
    output.close();
  } else if (params.sessiontype.get() == "python") {
    // open in overwrite mode, as we write full python script
    std::ofstream output(filename.c_str());
    ActionQueue::getInstance().outputAsPython(output);
    output.close();
  } else
    ASSERT(0, "CommandStoreSessionAction::performCall() - unknown session type "
        +params.sessiontype.get()+".");

  return Action::success;
}

ActionState::ptr CommandStoreSessionAction::performUndo(ActionState::ptr _state) {
//  CommandStoreSessionState *state = assert_cast<CommandStoreSessionState*>(_state.get());

  return _state;
}

ActionState::ptr CommandStoreSessionAction::performRedo(ActionState::ptr _state){
  //  CommandStoreSessionState *state = assert_cast<CommandStoreSessionState*>(_state.get());

    return _state;
}

bool CommandStoreSessionAction::canUndo() {
  return false;
}

bool CommandStoreSessionAction::shouldUndo() {
  return false;
}
/** =========== end of function ====================== */
